// src/components/kanban/KanbanCardPreview.tsx
"use client"

import { cn } from "@/lib/utils"
import { KanbanCardData } from "@/types/kanban"
import { useDraggable } from "@dnd-kit/core"
import { PointerEvent, useRef } from "react"

interface KanbanCardPreviewProps {
  card: KanbanCardData
  onClick: () => void
}

export function KanbanCardPreview({ card, onClick }: KanbanCardPreviewProps) {
  const {
    attributes,
    listeners = {},
    setNodeRef,
    transform,
    isDragging,
  } = useDraggable({
    id: card.id,
    data: { card },
  })

  const dragThreshold = 5
  const pointerStart = useRef<{ x: number; y: number } | null>(null)

  const handlePointerDown = (e: PointerEvent) => {
    pointerStart.current = { x: e.clientX, y: e.clientY }
    listeners.onPointerDown?.(e)
  }

  const handlePointerUp = (e: PointerEvent) => {
    if (!pointerStart.current) return
    const dx = Math.abs(e.clientX - pointerStart.current.x)
    const dy = Math.abs(e.clientY - pointerStart.current.y)
    const isDrag = dx > dragThreshold || dy > dragThreshold
    if (!isDrag) {
      onClick()
    }
    pointerStart.current = null
  }

  const todoCount = card.todos?.length ?? 0
  const doneCount = card.todos?.filter((t) => t.done).length ?? 0

  return (
    <div
      ref={setNodeRef}
      {...attributes}
      {...listeners}
      onPointerDown={handlePointerDown}
      onPointerUp={handlePointerUp}
      style={{
        transform: transform
          ? `translate3d(${transform.x}px, ${transform.y}px, 0)`
          : undefined,
        opacity: isDragging ? 0.5 : 1,
      }}
      className={cn(
        "rounded-md bg-card p-3 shadow transition-all cursor-pointer select-none",
        isDragging && "ring-2 ring-ring"
      )}
    >
      <div className="flex gap-1 mb-1 flex-wrap">
        {card.labels?.map((label) => (
          <div
            key={label.id}
            className="w-3 h-3 rounded-full"
            style={{ backgroundColor: label.color }}
            title={label.name}
          />
        ))}
      </div>
      <h3 className="font-medium text-sm mb-1">{card.title}</h3>
      <div className="text-xs text-muted-foreground">
        {doneCount}/{todoCount} ToDos
      </div>
    </div>
  )
}
